@@ -43,28 +43,14 @@
 
 static void *world_create(libtest::server_startup_st& servers, test_return_t& error)
 {
-  if (libtest::has_memcached() == false)
-  {
-    error= TEST_SKIPPED;
-    return NULL;
-  }
+  SKIP_UNLESS(libtest::has_libmemcached());
 
   if (servers.sasl())
   {
-    if (LIBMEMCACHED_WITH_SASL_SUPPORT == 0)
-    {
-      error= TEST_SKIPPED;
-      return NULL;
-    }
+    SKIP_UNLESS(libtest::has_libmemcached_sasl());
 
-    if (HAVE_MEMCACHED_SASL_BINARY == 0)
-    {
-      error= TEST_SKIPPED;
-      return NULL;
-    }
-    
     // Assume we are running under valgrind, and bail
-    if (getenv("TESTS_ENVIRONMENT"))
+    if (getenv("LOG_COMPILER"))
     {
       error= TEST_SKIPPED;
       return NULL;
@@ -101,11 +87,13 @@ static void *world_create(libtest::server_startup_st& servers, test_return_t& er
 static bool world_destroy(void *object)
 {
   libmemcached_test_container_st *container= (libmemcached_test_container_st *)object;
+#if 0
 #if defined(LIBMEMCACHED_WITH_SASL_SUPPORT) && LIBMEMCACHED_WITH_SASL_SUPPORT
   if (LIBMEMCACHED_WITH_SASL_SUPPORT)
   {
     sasl_done();
   }
+#endif
 #endif
 
   delete container;
